/*
    (C) 1995-98 AROS - The Amiga Research OS
    $Id: newloadseg.c,v 1.2 2007/08/13 22:51:13 laire Exp $

    Desc: DOS function NewLoadSeg()
    Lang: english

*/
#include <dos/dos.h>
#include <dos/dosextens.h>
#include <utility/tagitem.h>
#include <proto/dos.h>
#include <proto/exec.h>
#include "dos_intern.h"

BPTR	LIB_LoadSeg(char *);

/*****************************************************************************

    NAME */
#include <proto/dos.h>

        AROS_LH2(BPTR, NewLoadSeg,

/*  SYNOPSIS */
        AROS_LHA(STRPTR, file, D1),
	AROS_LHA(struct TagItem *, tags, D2),

/*  LOCATION */
        struct DosLibrary *, DOSBase, 128, Dos)

/*  FUNCTION
        Loads an executable file into memory via LoadSeg() and takes
        additional actions based upon the supplied tags.

    INPUTS
        file - NULL terminated name of the file
        tags - pointer to the tagitems

    RESULT
        Handle to the loaded executable or 0 if the load failed.
        IoErr() gives additional information in that case.

    NOTES

    EXAMPLE

    BUGS
        As there are no tags currently defined all this function does is
        call LoadSeg()

    SEE ALSO
        LoadSeg(), UnLoadSeg(), InternalLoadSeg(), InternalUnloadSeg()

    INTERNALS

    HISTORY

*****************************************************************************/
{
  AROS_LIBFUNC_INIT
  AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

  DEBUG_LOADSEG(dprintf("NewLoadSeg: name = \"%s\", tags = $%lx\n", file, (ULONG) tags));

  FAILFORTASKNP(return 0;)

  return LoadSeg(file);

  AROS_LIBFUNC_EXIT
} /* NewLoadSeg */
